import{_ as t}from"./NewEditor-BRnn5ufh.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},f=new Error().stack;f&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[f]="b394c9fd-42f5-4ed4-9f04-bbff611bca8d",e._sentryDebugIdIdentifier="sentry-dbid-b394c9fd-42f5-4ed4-9f04-bbff611bca8d")}catch{}})();function c(e,f){e.accDescr&&f.setAccDescription?.(e.accDescr),e.accTitle&&f.setAccTitle?.(e.accTitle),e.title&&f.setDiagramTitle?.(e.title)}t(c,"populateCommonDb");export{c as p};
//# sourceMappingURL=chunk-4BX2VUAB-IWR8qdJd.js.map
