.file-link[data-v-795359ad]{color:var(--ac-brand-primary);text-decoration:underline;cursor:pointer}.file-link[data-v-795359ad]:hover{opacity:.8}.log-highlight[data-v-795359ad]{background-color:var(--ac-color-warning);color:inherit;border-radius:2px;padding:0 1px}.cli[data-v-b7b6fb15]{background-color:var(--ac-terminal-bg);border-radius:5px;padding:10px;color:var(--ac-terminal-text);font-family:monospace;overflow-x:hidden;word-break:break-all;white-space:pre-wrap;max-width:100%}.cli .copy-button[data-v-b7b6fb15]{position:absolute;top:4px;right:4px;z-index:10;color:var(--ac-text-tertiary);display:flex;align-items:center;justify-content:center;padding:4px}.cli .copy-button[data-v-b7b6fb15]:hover{color:var(--ac-terminal-text)}.copy-btn[data-v-902b145e]{color:var(--ac-text-tertiary);display:flex;align-items:center;justify-content:center;padding:4px;flex-shrink:0}.copy-btn[data-v-902b145e]:hover{color:var(--ac-text-primary)}.body-content[data-v-e3c5f651]{margin:4px 0 0;padding:8px;background-color:var(--ac-bg-secondary);border-radius:4px;white-space:pre-wrap;word-break:break-all;font-family:monospace;font-size:12px;max-height:200px;overflow:auto}[data-v-e3c5f651] .ant-collapse-header{padding:0!important}[data-v-e3c5f651] .ant-collapse-content-box{padding:4px 0!important}.body-content[data-v-e2be4c22]{margin:4px 0 0;padding:8px;background-color:var(--ac-bg-secondary);border-radius:4px;white-space:pre-wrap;word-break:break-all;font-family:monospace;font-size:12px;max-height:200px;overflow:auto}[data-v-e2be4c22] .ant-collapse-header{padding:0!important}[data-v-e2be4c22] .ant-collapse-content-box{padding:4px 0!important}.fix-with-ai[data-v-3c0a5f81]{display:flex;gap:4px;align-items:center;cursor:pointer;color:var(--ac-brand-primary);font-size:12px;padding:0 8px}.fix-with-ai[data-v-3c0a5f81]:hover{opacity:.8}.fix-with-ai.disabled[data-v-3c0a5f81]{cursor:not-allowed;opacity:.5}
