import{aX as r,aY as n,a5 as o,aZ as c,a_ as p,a$ as b,b0 as d,b1 as f,b2 as m,b3 as s,b4 as u,b5 as g,b6 as l}from"./jwt-decode.esm-BYfS37aG.js";import{b as y,s as w,g as _}from"./workspaceStore-CMQaTfN3.js";import{_ as h}from"./App.vue_vue_type_style_index_0_lang-BcDoOAx-.js";import{r as i}from"./router-DcQANWsf.js";import"./userStore-ZzGDEfJ0.js";import"./runnerData-CFJzN8JX.js";import"./url-xbaQsfJ1.js";import"./colorHelpers-Dr5wl109.js";import"./PlayerConfigProvider-9KPuGDRT.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="1fecbc6d-0c5b-4f65-abaf-9bc3895a0b81",t._sentryDebugIdIdentifier="sentry-dbid-1fecbc6d-0c5b-4f65-abaf-9bc3895a0b81")}catch{}})();class I{static init(){setInterval(()=>{y("/_healthcheck").catch(()=>{})},20*1e3)}}(async()=>{await w();const t=await _(),a=r(),e=n({render:()=>o(h)});c.init(),p(e,i,t),I.init(),e.use(i),e.use(a),e.use(b),e.mount("#app"),e.component("VSelect",d),e.component("Markdown",f),e.component("Message",m),s(e,u),s(e,g),s(e,l)})();
//# sourceMappingURL=player-Bur3aD6Q.js.map
