import{v as o,ab as u,ad as d}from"./jwt-decode.esm-BYfS37aG.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="5b330568-54e9-4495-ad81-45fbd53a8aae",e._sentryDebugIdIdentifier="sentry-dbid-5b330568-54e9-4495-ad81-45fbd53a8aae")}catch{}})();function i(e){for(var t=1;t<arguments.length;t++){var r=arguments[t]!=null?Object(arguments[t]):{},n=Object.keys(r);typeof Object.getOwnPropertySymbols=="function"&&(n=n.concat(Object.getOwnPropertySymbols(r).filter(function(a){return Object.getOwnPropertyDescriptor(r,a).enumerable}))),n.forEach(function(a){f(e,a,r[a])})}return e}function f(e,t,r){return t in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}var l=function(t,r){var n=i({},t,r.attrs);return o(u,i({},n,{icon:d}),null)};l.displayName="CloseCircleOutlined";l.inheritAttrs=!1;export{l as C};
//# sourceMappingURL=CloseCircleOutlined-DtNcYD9v.js.map
