import{_ as o,d}from"./NewEditor-BRnn5ufh.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="9f7f2b04-aedd-452c-84be-875d15ece263",e._sentryDebugIdIdentifier="sentry-dbid-9f7f2b04-aedd-452c-84be-875d15ece263")}catch{}})();var b=o((e,n)=>{let t;return n==="sandbox"&&(t=d("#i"+e)),(n==="sandbox"?d(t.nodes()[0].contentDocument.body):d("body")).select(`[id="${e}"]`)},"getDiagramElement");export{b as g};
//# sourceMappingURL=chunk-55IACEB6-BZtPDHoI.js.map
