import{b as r}from"./router-D53qV9Zg.js";import"./jwt-decode.esm-BYfS37aG.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="f7aa3d90-829e-4bb6-a9ab-a921faa2a1ac",a._sentryDebugIdIdentifier="sentry-dbid-f7aa3d90-829e-4bb6-a9ab-a921faa2a1ac")}catch{}})();class i{async create(e){return r.post(`organizations/${e.organizationId}/members`,{email:e.email,folderIds:e.folderIds})}async delete(e){return r.delete(`organizations/${e.organizationId}/members/${e.authorId}`)}async list(e){return r.get(`organizations/${e}/members`)}async get(e,n){return r.get(`organizations/${e}/members/${n}`)}async update(e,n,t){return r.patch(`organizations/${e}/members/${n}`,t)}}export{i as M};
//# sourceMappingURL=member-dJywfr1G.js.map
