.connector-card[data-v-55601ef3]{cursor:pointer;transition:all .3s}.connector-card[data-v-55601ef3]:hover{box-shadow:0 0 15px var(--ac-shadow-color)}.connector-card.unavailable[data-v-55601ef3]{opacity:.7}.connector-card.unavailable[data-v-55601ef3]:hover{box-shadow:none}.connectors-grid[data-v-c13d4a8d]{display:grid;grid-template-columns:repeat(auto-fill,minmax(300px,1fr));gap:20px}.connector-search[data-v-c13d4a8d]{width:300px;margin-bottom:40px}.connector-search[data-v-c13d4a8d] .ant-input{border-color:var(--ac-border-primary)}.connector-search[data-v-c13d4a8d] .ant-input-search-button{background-color:var(--ac-brand-primary);border-color:var(--ac-brand-primary)}.connector-search[data-v-c13d4a8d] .ant-input-search-button .anticon{color:var(--ac-text-inverse)}.connector-search[data-v-c13d4a8d] .ant-input-search-button:hover{background-color:var(--ac-brand-primary);border-color:var(--ac-brand-primary);opacity:.85}
