import{_ as k}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-CSc1qEVg.js";import{A as h}from"./constants-BEWVx_ZC.js";import{e as v,b as w,ak as A,l as o,f as B,v as i,n as m,j as p,w as t,p as e,am as I,b7 as _,B as x,q as a,t as u,k as C,b8 as N,ag as T,g as c,aO as D}from"./jwt-decode.esm-BYfS37aG.js";import{u as E}from"./workspaceStore-CMQaTfN3.js";import{C as S}from"./index-DwiPTllg.js";import"./logo-BiWG9_W5.js";import"./Logo-DKvJNxAR.js";import"./userStore-ZzGDEfJ0.js";import"./runnerData-CFJzN8JX.js";import"./url-xbaQsfJ1.js";import"./colorHelpers-Dr5wl109.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new j().stack;d&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[d]="24e9a6a8-b5c3-4f05-919c-77452bf3d6f3",r._sentryDebugIdIdentifier="sentry-dbid-24e9a6a8-b5c3-4f05-919c-77452bf3d6f3")}catch{}})();const R={class:"inner-content"},V={class:"card-content"},H=v({__name:"Error",setup(r){const d=A(),g=T(),f=E(),b=w(()=>f.state.workspace?.name??f.state.workspace?.brandName),n=w(()=>{const{status:l}=d.params;switch(l){case"404":return{status:l,title:o.translate("i18n_page_not_found"),message:o.translate("i18n_page_not_found_message"),showAd:!1};case"403":return{status:l,title:o.translate("i18n_access_denied"),message:o.translate("i18n_access_denied_message"),action:"Go back to home",showAd:!0};default:return{status:"500",title:o.translate("i18n_internal_error"),message:o.translate("i18n_internal_error_message"),showAd:!1}}}),y=()=>{g.push({name:"playerHome"})};return(l,s)=>(c(),B("div",R,[i(e(I),null,{default:t(()=>[a(u(n.value.title),1)]),_:1}),i(e(_),{class:"message"},{default:t(()=>[a(u(n.value.message),1)]),_:1}),n.value.action?(c(),m(e(x),{key:0,type:"link",onClick:y},{default:t(()=>[a(u(n.value.action),1)]),_:1})):p("",!0),n.value.showAd?(c(),m(e(S),{key:1,bordered:!1,class:"card"},{default:t(()=>[C("div",V,[i(k,{style:{"margin-bottom":"10px"}}),i(e(_),null,{default:t(()=>[a("This page is part of "+u(b.value?`the ${b.value}`:"a")+" workflow, built with Abstra.",1)]),_:1}),e(f).state.workspace?(c(),m(e(_),{key:0},{default:t(()=>[s[1]||(s[1]=a("Automate your own processes by getting started ",-1)),i(e(N),{href:e(h).HOMEPAGE},{default:t(()=>[...s[0]||(s[0]=[a("here",-1)])]),_:1},8,["href"]),s[2]||(s[2]=a(".",-1))]),_:1})):p("",!0)])]),_:1})):p("",!0)]))}}),j=D(H,[["__scopeId","data-v-522ad0d4"]]);export{j as default};
//# sourceMappingURL=Error-FDpkYZpT.js.map
