.tooltip-box[data-v-b7f18fed]{position:relative;display:inline-block}.tooltip-box:hover .tooltip[data-v-b7f18fed]{opacity:1}.tooltip[data-v-b7f18fed]{display:flex;justify-content:center;align-items:center;color:var(--ac-text-inverse);text-align:center;padding:4px 8px;border-radius:3px;font-size:10px;font-weight:500;line-height:12px;cursor:default;-webkit-user-select:none;user-select:none;width:77px;min-height:20px;opacity:0;transition:opacity 1s;position:absolute;z-index:3;background:var(--ac-text-secondary)}.menu-item svg[data-v-09abc185]{margin-bottom:-2px}.container[data-v-09abc185]{display:flex;flex-direction:column;height:100%;width:200px;overflow:hidden;justify-content:space-between;background-color:var(--ac-bg-primary)}.upper[data-v-09abc185]{overflow-y:auto;flex-grow:1;height:100%}.lower[data-v-09abc185]{background-color:var(--ac-bg-primary);border-right:1px solid var(--ac-border-primary);flex-grow:0}[data-v-09abc185] .ant-menu-item-group-title{font-size:10px;text-transform:uppercase;letter-spacing:.05em;padding:12px 16px 4px;line-height:1}[data-v-09abc185] .ant-menu-item-selected{box-shadow:inset 2px 0 0 var(--ac-brand-primary)}.button[data-v-8b588485]{height:50px;display:flex;justify-content:center}
