import{e as l,b as o,f as t,j as r,I as c,t as f,bh as g,g as s,aO as u}from"./jwt-decode.esm-BYfS37aG.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="0b887d90-42f4-4d3f-af79-9d45a2f69cd6",e._sentryDebugIdIdentifier="sentry-dbid-0b887d90-42f4-4d3f-af79-9d45a2f69cd6")}catch{}})();const m={class:"logo"},b=["src","alt"],y=l({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){g(i=>({v4521d904:n.value}));const a=e,n=o(()=>a.size==="small"?"24px":a.size==="large"?"80px":"50px"),d=o(()=>`${a.brandName} Logo`);return(i,p)=>(s(),t("div",m,[e.imageUrl?(s(),t("img",{key:0,class:"logo-img",src:e.imageUrl,alt:d.value},null,8,b)):r("",!0),e.hideText?r("",!0):(s(),t("span",{key:1,class:c(e.size)},f(e.brandName),3))]))}}),_=u(y,[["__scopeId","data-v-8f34aac0"]]);export{_ as L};
//# sourceMappingURL=Logo-DKvJNxAR.js.map
