import{_ as p}from"./Login.vue_vue_type_script_setup_true_lang-Dh30ZzIy.js";import{e as i,f as u,v as d,p as n,ag as m,ak as f,g as l,aO as _}from"./jwt-decode.esm-BYfS37aG.js";import{u as g}from"./workspaceStore-CMQaTfN3.js";import"./OTPInput-B76NLryy.js";import"./Logo-DKvJNxAR.js";import"./string-IQGGUV40.js";import"./CircularLoading-DSsC5jij.js";import"./index-D2Zf-HsM.js";import"./userStore-ZzGDEfJ0.js";import"./runnerData-CFJzN8JX.js";import"./url-xbaQsfJ1.js";import"./colorHelpers-Dr5wl109.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="a655ea56-b76f-4285-9cec-c51f98d0694a",e._sentryDebugIdIdentifier="sentry-dbid-a655ea56-b76f-4285-9cec-c51f98d0694a")}catch{}})();const y={class:"runner"},b=i({__name:"Login",setup(e){const o=m(),r=f(),a=g(),c=async()=>{const{redirect:t,...s}=r.query;if(t){await o.push({path:t,query:s,params:r.params});return}o.push({name:"playerHome",query:s})};return(t,s)=>(l(),u("div",y,[d(p,{"logo-url":n(a).state.workspace?.logoUrl??void 0,"brand-name":n(a).state.workspace?.brandName,locale:n(a).state.workspace?.language??"en",onDone:c},null,8,["logo-url","brand-name","locale"])]))}}),R=_(b,[["__scopeId","data-v-12c690e1"]]);export{R as default};
//# sourceMappingURL=Login-Cy9QM_Kt.js.map
