import{a9 as y,aa as n}from"./jwt-decode.esm-BYfS37aG.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="a056ea64-6b26-4c43-8f91-3937584953a7",e._sentryDebugIdIdentifier="sentry-dbid-a056ea64-6b26-4c43-8f91-3937584953a7")}catch{}})();function f(e){return n.isArray(e)?e.length===0?"[ ]":"[ ... ]":n.isObject(e)?Object.keys(e).length===0?"{ }":"{ ... }":n.isString(e)?`'${e}'`:n.isUndefined(e)||n.isNull(e)?"None":e===!0?"True":e===!1?"False":`${e}`}function u(e){if(n.isArray(e))return"array";if(n.isObject(e))return"object";throw new Error("treeKey called with non-object and non-array")}function c(e,r=[],i){const l=i?`'${i}': ${f(e)}`:f(e);if(n.isArray(e)){const t=u(e);return[{title:l,key:[...r,t].join("/"),rawData:e,children:e.flatMap((s,o)=>c(s,[...r,t,`${o}`]))}]}else if(n.isObject(e)){const t=u(e);return[{title:l,key:[...r,t].join("/"),rawData:e,children:Object.entries(e).flatMap(([s,o])=>c(o,[...r,t,s],s))}]}else return[{title:l,key:r.join("/"),rawData:e,children:[]}]}function w(e,r){return new Promise(i=>{y.confirm({title:e,onOk:()=>i(!0),okText:r?.okText,onCancel:()=>i(!1),cancelText:r?.cancelText})})}export{w as a,c as t};
//# sourceMappingURL=ant-design-2HB1Oiwt.js.map
