import{i as c}from"./url-xbaQsfJ1.js";import"./jwt-decode.esm-BYfS37aG.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="d365a811-a49d-474b-a7ca-e089237e164f",e._sentryDebugIdIdentifier="sentry-dbid-d365a811-a49d-474b-a7ca-e089237e164f")}catch{}})();function i(e){return e.startsWith("/")?e.slice(1):e}function f(e,r,n={}){if(c(r)){const a=new URL(r),t=new URLSearchParams(n),o=new URLSearchParams(a.search),s=new URLSearchParams([...o,...t]);return a.search=s.toString(),{action:"REPLACE_LOCAL_HREF",newHref:a.toString()}}else{const a=r.replace(/\/$/,"");if(e==="player")return{action:"GOTO_FORM_PLAYER",path:i(a),queryParams:n};if(e==="editor")return{action:"GOTO_FORM_EDITOR",path:i(a),queryParams:n};if(e==="preview")return{action:"GOTO_FORM_PLAYER",path:i(a),queryParams:n};throw new Error(`Invalid routing ${e}`)}}async function w(e,r,n,a={}){const t=f(e,n,a);switch(t.action){case"REPLACE_LOCAL_HREF":window.location.href=t.newHref;break;case"GOTO_FORM_EDITOR":await r.push({name:"formEditor",params:{formPath:t.path},query:t.queryParams});break;case"GOTO_FORM_PLAYER":await r.push({name:e==="preview"?"formPreview":"formPlayer",params:{formPath:t.path},query:t.queryParams});break;default:throw new Error("Invalid routing")}}export{w as r};
//# sourceMappingURL=redirect-wT-Y8Zfd.js.map
