const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/OidcLoginCallback-BlLDJi_n.js","assets/workspaceStore-CMQaTfN3.js","assets/jwt-decode.esm-BYfS37aG.js","assets/jwt-decode-D2XcxCrM.css","assets/userStore-ZzGDEfJ0.js","assets/runnerData-CFJzN8JX.js","assets/url-xbaQsfJ1.js","assets/colorHelpers-Dr5wl109.js","assets/OidcLogoutCallback-Cmy-fuqV.js","assets/Login-Cy9QM_Kt.js","assets/Login.vue_vue_type_script_setup_true_lang-Dh30ZzIy.js","assets/OTPInput-B76NLryy.js","assets/OTPInput-DkitIIgo.css","assets/Logo-DKvJNxAR.js","assets/Logo-D2kepPyK.css","assets/string-IQGGUV40.js","assets/CircularLoading-DSsC5jij.js","assets/CircularLoading-BiyobKo3.css","assets/index-D2Zf-HsM.js","assets/Login-CfTVNGsW.css","assets/Login-ChYgW3Ij.css","assets/Main-CT3_-qZo.js","assets/PlayerNavbar-8P26xy1l.js","assets/metadata-9Sy_Y2Gz.js","assets/PhCursorClick.vue-mvNh3JMs.js","assets/PhHouse.vue-DRZ39az5.js","assets/PhMagnifyingGlass.vue-DmAWc16f.js","assets/PhWebhooksLogo.vue-2SCNyr8o.js","assets/LoadingOutlined-CyONonpC.js","assets/PhSignOut.vue-DOsKwdz-.js","assets/index-B_8hGuYH.js","assets/PlayerNavbar-DAUZYUrK.css","assets/Main-q9PQMe3g.css","assets/Home-CI6CcMAU.js","assets/Watermark-BNe5HOS9.js","assets/constants-BEWVx_ZC.js","assets/Watermark-o-wolLMc.css","assets/PageStageView-DAPtpvJZ.js","assets/consoleCapture-BPVon_ip.js","assets/PageStageView-B6V7P4e9.css","assets/PhArrowSquareOut.vue-D4srLpe_.js","assets/index-DwiPTllg.js","assets/Home-DoQD4uFs.css","assets/Error-FDpkYZpT.js","assets/AbstraLogo.vue_vue_type_script_setup_true_lang-CSc1qEVg.js","assets/logo-BiWG9_W5.js","assets/Error-CIbhyrKS.css","assets/Form-BvmEXZ_E.js","assets/FormRunner-Ct8jAHcJ.js","assets/Steps-fw8in-jn.js","assets/index-Bpjq9G-y.js","assets/Steps-C-jqXtQm.css","assets/FormRunner-BzLbFxEW.css","assets/redirect-wT-Y8Zfd.js","assets/asyncComputed-Dxf4RCwC.js","assets/uuid-CHgzk6MJ.js","assets/Form-TwePofFo.css"])))=>i.map(i=>d[i]);
import{c as u,a as d,_ as t,u as l}from"./jwt-decode.esm-BYfS37aG.js";import{u as p}from"./userStore-ZzGDEfJ0.js";import{a as _}from"./workspaceStore-CMQaTfN3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="cf5accf6-aeb8-4ec9-818d-b0c15c139299",e._sentryDebugIdIdentifier="sentry-dbid-cf5accf6-aeb8-4ec9-818d-b0c15c139299")}catch{}})();const h=[{path:"/oidc-login-callback",name:"oidcLoginCallback",component:()=>t(()=>import("./OidcLoginCallback-BlLDJi_n.js"),__vite__mapDeps([0,1,2,3,4,5,6,7])),meta:{allowUnauthenticated:!0}},{path:"/oidc-logout-callback",name:"oidcLogoutCallback",component:()=>t(()=>import("./OidcLogoutCallback-Cmy-fuqV.js"),__vite__mapDeps([8,1,2,3,4,5,6,7])),meta:{allowUnauthenticated:!0}},{path:"/login",name:"playerLogin",component:()=>t(()=>import("./Login-Cy9QM_Kt.js"),__vite__mapDeps([9,10,2,3,1,4,5,6,7,11,12,13,14,15,16,17,18,19,20])),meta:{allowUnauthenticated:!0}},{path:"/",name:"main",component:()=>t(()=>import("./Main-CT3_-qZo.js"),__vite__mapDeps([21,22,4,2,3,1,5,6,7,23,24,25,26,27,28,29,30,31,32])),redirect:{name:"main"},children:[{path:"",name:"playerHome",component:()=>t(()=>import("./Home-CI6CcMAU.js"),__vite__mapDeps([33,23,24,2,3,25,26,27,34,1,4,5,6,7,35,36,37,16,17,38,39,40,41,28,42])),meta:{title:"Home"}},{path:"_player/threads",redirect:{name:"playerThreads"}},{path:"error/:status",name:"error",component:()=>t(()=>import("./Error-FDpkYZpT.js"),__vite__mapDeps([43,44,45,13,2,3,14,35,1,4,5,6,7,41,46])),meta:{allowUnauthenticated:!0}},{path:":path(.*)*",name:"form",component:()=>t(()=>import("./Form-BvmEXZ_E.js"),__vite__mapDeps([47,4,2,3,37,16,17,34,1,5,6,7,35,36,38,39,48,10,11,12,13,14,15,18,19,49,50,51,52,53,54,55,56])),meta:{hideLogin:!0}}]}],i=u({history:d("/"),routes:h,scrollBehavior(e){if(e.hash)return{el:e.hash}}}),f=e=>async(a,o)=>{if(l(a,o),a.meta.allowUnauthenticated)return;const r=p();r.loadJWT();const c=await _(a.path),{redirect:s,...m}=a.query;switch(c.status){case"ALLOWED":break;case"UNAUTHORIZED":{const n=r.email;r.removeJWT(),await e.push({name:"playerLogin",query:{...m,redirect:s||a.path,reauth:n?"true":void 0,email:n||void 0},params:a.params});break}case"NOT_FOUND":await e.push({name:"error",params:{status:"404"}});break;default:await e.push({name:"error",params:{status:"403"}})}};i.beforeEach(f(i));export{h as a,f as g,i as r};
//# sourceMappingURL=router-DcQANWsf.js.map
