.page-container[data-v-dcbf338d]{width:100%;height:100%;display:flex;position:relative;flex-direction:column;align-items:center}.loading[data-v-dcbf338d]{display:flex;flex-grow:1;justify-content:center;align-items:center;height:100%;width:100%}.error-container[data-v-dcbf338d]{display:flex;flex-grow:1;justify-content:center;align-items:center;height:100%;width:100%;color:var(--ac-text-secondary, #64748b);font-size:16px}.page-iframe[data-v-dcbf338d]{width:100%;height:100%;border:none;flex:1}
