@import"https://cdn.jsdelivr.net/npm/@vue-flow/core@1.41.7/dist/style.css";@import"https://cdn.jsdelivr.net/npm/@vue-flow/core@1.41.7/dist/theme-default.css";@import"https://cdn.jsdelivr.net/npm/@vue-flow/controls@latest/dist/style.css";@import"https://cdn.jsdelivr.net/npm/@vue-flow/minimap@latest/dist/style.css";@import"https://cdn.jsdelivr.net/npm/@vue-flow/node-resizer@latest/dist/style.css";.basic-flow[data-v-edf33b66]{border:1px solid var(--ac-border-primary);border-radius:8px;background-color:var(--ac-bg-secondary)}html[data-v-edf33b66],body[data-v-edf33b66],#app[data-v-edf33b66]{margin:0;height:100%}#app[data-v-edf33b66]{text-transform:uppercase;font-family:JetBrains Mono,monospace;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;text-align:center;color:var(--ac-text-primary)}.vue-flow__minimap[data-v-edf33b66]{transform:scale(75%);transform-origin:bottom right}.basic-flow.dark[data-v-edf33b66]{background:var(--ac-bg-secondary);color:var(--ac-text-primary)}.basic-flow.dark .vue-flow__node[data-v-edf33b66]{background:var(--ac-bg-tertiary);color:var(--ac-text-primary)}.basic-flow.dark .vue-flow__node.selected[data-v-edf33b66]{background:var(--ac-bg-active);box-shadow:0 0 0 2px var(--ac-brand-link)}.basic-flow .vue-flow__controls[data-v-edf33b66]{display:flex;flex-wrap:wrap;justify-content:center}.basic-flow.dark .vue-flow__controls[data-v-edf33b66]{border:1px solid var(--ac-border-primary)}.basic-flow .vue-flow__controls .vue-flow__controls-button[data-v-edf33b66]{border:none;border-right:1px solid var(--ac-border-primary)}.basic-flow .vue-flow__controls .vue-flow__controls-button svg[data-v-edf33b66]{height:100%;width:100%}.basic-flow.dark .vue-flow__controls .vue-flow__controls-button[data-v-edf33b66]{background:var(--ac-bg-elevated);fill:var(--ac-text-primary);border:none}.basic-flow.dark .vue-flow__controls .vue-flow__controls-button[data-v-edf33b66]:hover{background:var(--ac-bg-hover)}.basic-flow.dark .vue-flow__edge-textbg[data-v-edf33b66]{fill:var(--ac-bg-secondary)}.basic-flow.dark .vue-flow__edge-text[data-v-edf33b66]{fill:var(--ac-text-primary)}.basic-flow.dark[data-v-edf33b66] .vue-flow__minimap{background-color:var(--ac-bg-primary)}.basic-flow.dark[data-v-edf33b66] .vue-flow__minimap-mask{fill:var(--ac-bg-secondary);opacity:.8}.basic-flow.dark[data-v-edf33b66] .vue-flow__minimap-node{fill:var(--ac-border-secondary);stroke:none}.vue-flow__handle[data-v-edf33b66]{opacity:0}.diagram-table-card[data-v-edf33b66]{width:300px;height:320px}.diagram-table-card[data-v-edf33b66] .table-card{width:300px;height:320px;min-width:300px}.diagram-table-card[data-v-edf33b66] .columns-list{max-height:220px;overflow-y:auto}
