import{_ as n}from"./NewEditor-BRnn5ufh.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="56806fc3-fc0c-4013-9e48-2b139bfae5be",e._sentryDebugIdIdentifier="sentry-dbid-56806fc3-fc0c-4013-9e48-2b139bfae5be")}catch{}})();var i=n(()=>`
  /* Font Awesome icon styling - consolidated */
  .label-icon {
    display: inline-block;
    height: 1em;
    overflow: visible;
    vertical-align: -0.125em;
  }
  
  .node .label-icon path {
    fill: currentColor;
    stroke: revert;
    stroke-width: revert;
  }
`,"getIconStyles");export{i as g};
//# sourceMappingURL=chunk-FMBD7UC4-CngmyREj.js.map
