.v-spinner .v-beat[data-v-224007fd]{-webkit-animation:v-beatStretchDelay-224007fd .7s infinite linear;animation:v-beatStretchDelay-224007fd .7s infinite linear;-webkit-animation-fill-mode:both;animation-fill-mode:both;display:inline-block}.v-spinner .v-beat-odd[data-v-224007fd]{animation-delay:0s}.v-spinner .v-beat-even[data-v-224007fd]{animation-delay:.35s}@-webkit-keyframes v-beatStretchDelay-224007fd{50%{-webkit-transform:scale(.75);transform:scale(.75);-webkit-opacity:.2;opacity:.2}to{-webkit-transform:scale(1);transform:scale(1);-webkit-opacity:1;opacity:1}}@keyframes v-beatStretchDelay-224007fd{50%{-webkit-transform:scale(.75);transform:scale(.75);-webkit-opacity:.2;opacity:.2}to{-webkit-transform:scale(1);transform:scale(1);-webkit-opacity:1;opacity:1}}.content[data-v-c9eeae4b]{display:flex;justify-content:center;align-items:center;height:100%;width:100%}
