import{_ as n,e as u,l as w}from"./NewEditor-BRnn5ufh.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="3010aace-94e9-409c-b470-d627a153f069",e._sentryDebugIdIdentifier="sentry-dbid-3010aace-94e9-409c-b470-d627a153f069")}catch{}})();var y=n((e,t,i,r)=>{e.attr("class",i);const{width:o,height:a,x:d,y:c}=h(e,t);u(e,a,o,r);const s=f(d,c,o,a,t);e.attr("viewBox",s),w.debug(`viewBox configured: ${s} with padding: ${t}`)},"setupViewPortForSVG"),h=n((e,t)=>{const i=e.node()?.getBBox()||{width:0,height:0,x:0,y:0};return{width:i.width+t*2,height:i.height+t*2,x:i.x,y:i.y}},"calculateDimensionsWithPadding"),f=n((e,t,i,r,o)=>`${e-o} ${t-o} ${i} ${r}`,"createViewBox");export{y as s};
//# sourceMappingURL=chunk-KX2RTZJC-BJBDrYNs.js.map
