import{e as o,b as s,f as l,g as i,k as r,h as c,J as f,I as d,aO as u}from"./jwt-decode.esm-BYfS37aG.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="6ff41556-077b-4087-a659-5c723dddcbcd",e._sentryDebugIdIdentifier="sentry-dbid-6ff41556-077b-4087-a659-5c723dddcbcd")}catch{}})();const y=o({__name:"ContentLayout",props:{fullWidth:{type:Boolean},noPadding:{type:Boolean},flexLayout:{type:Boolean},innerPadding:{}},setup(e){const n=e,t=s(()=>({...n.innerPadding&&{padding:n.innerPadding}}));return(a,g)=>(i(),l("div",{class:d(["content-layout",{"no-padding":e.noPadding}])},[r("div",{class:d(["centered-layout",{"full-width":e.fullWidth,"flex-layout":e.flexLayout}]),style:f(t.value)},[c(a.$slots,"default",{},void 0,!0)],6)],2))}}),b=u(y,[["__scopeId","data-v-00e066e8"]]);export{b as C};
//# sourceMappingURL=ContentLayout-DHTMjAzS.js.map
