import{aO as r,f as o,h as s,k as n,j as a,g as d}from"./jwt-decode.esm-BYfS37aG.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="0b93f0a5-2747-43e1-b300-2713c30a531f",e._sentryDebugIdIdentifier="sentry-dbid-0b93f0a5-2747-43e1-b300-2713c30a531f")}catch{}})();const c={},i={class:"base-layout"},f={class:"base-middle"},l={class:"content"},u={class:"left"},_={key:0,class:"base-footer"},b={key:0};function y(e,t){return d(),o("div",i,[s(e.$slots,"sidebar",{},void 0,!0),n("section",f,[s(e.$slots,"navbar",{},void 0,!0),n("section",l,[n("section",u,[s(e.$slots,"content",{},void 0,!0),e.$slots.footer?(d(),o("section",_,[s(e.$slots,"footer",{},void 0,!0)])):a("",!0)]),e.$slots.chat?(d(),o("section",b,[s(e.$slots,"chat",{},void 0,!0)])):a("",!0)])])])}const g=r(c,[["render",y],["__scopeId","data-v-a9f53d25"]]);export{g as B};
//# sourceMappingURL=BaseLayout-DElsrb1B.js.map
