import{O as d}from"./workspaceStore-CMQaTfN3.js";import{e as c,Q as u,f,v as o,w as n,p as a,am as _,T as p,q as r,t as s,l as i,g as m}from"./jwt-decode.esm-BYfS37aG.js";import"./userStore-ZzGDEfJ0.js";import"./runnerData-CFJzN8JX.js";import"./url-xbaQsfJ1.js";import"./colorHelpers-Dr5wl109.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="d1019533-1a9e-455f-a142-a003ec5bf323",e._sentryDebugIdIdentifier="sentry-dbid-d1019533-1a9e-455f-a142-a003ec5bf323")}catch{}})();const D=c({__name:"OidcLogoutCallback",setup(e){return u(async()=>{await new d().logoutCallback()}),(t,l)=>(m(),f("div",null,[o(a(_),null,{default:n(()=>[r(s(a(i).translate("i18n_oidclogoutcallback_authenticated_title")),1)]),_:1}),o(a(p),null,{default:n(()=>[r(s(a(i).translate("i18n_oidclogoutcallback_close_window_message")),1)]),_:1})]))}});export{D as default};
//# sourceMappingURL=OidcLogoutCallback-Cmy-fuqV.js.map
