import{O as d}from"./workspaceStore-CMQaTfN3.js";import{e as c,Q as f,f as u,v as n,w as o,p as t,am as _,T as p,q as r,t as i,l as s,g as m}from"./jwt-decode.esm-BYfS37aG.js";import"./userStore-ZzGDEfJ0.js";import"./runnerData-CFJzN8JX.js";import"./url-xbaQsfJ1.js";import"./colorHelpers-Dr5wl109.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="c9ed10a5-a377-4c7f-8416-9235c1fab512",e._sentryDebugIdIdentifier="sentry-dbid-c9ed10a5-a377-4c7f-8416-9235c1fab512")}catch{}})();const D=c({__name:"OidcLoginCallback",setup(e){return f(async()=>{await new d().loginCallback()}),(a,l)=>(m(),u("div",null,[n(t(_),null,{default:o(()=>[r(i(t(s).translate("i18n_oidclogincallback_authenticated_title")),1)]),_:1}),n(t(p),null,{default:o(()=>[r(i(t(s).translate("i18n_oidclogincallback_close_window_message")),1)]),_:1})]))}});export{D as default};
//# sourceMappingURL=OidcLoginCallback-BlLDJi_n.js.map
