import{e as c,b as g,n as r,g as d,p as a,A as b,w as n,v as l,B as i,y as p,C as m,D as f,h as u,j as y,m as B}from"./jwt-decode.esm-BYfS37aG.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="63f9af3a-8a2d-4749-a9e2-58142f976364",e._sentryDebugIdIdentifier="sentry-dbid-63f9af3a-8a2d-4749-a9e2-58142f976364")}catch{}})();const w=c({__name:"AbstraButton",props:{disabledTooltip:{},tooltip:{},prefixCls:{},type:{},htmlType:{},shape:{},size:{},loading:{type:[Boolean,Object]},disabled:{type:Boolean},ghost:{type:Boolean},block:{type:Boolean},danger:{type:Boolean},icon:{},href:{},target:{},title:{},onClick:{type:[Function,Array]},onMousedown:{type:[Function,Array]}},setup(e){const t=g(()=>o.disabledTooltip&&o.disabled?o.disabledTooltip:o.tooltip),o=e;return(s,k)=>t.value?(d(),r(a(b),{key:0,title:t.value},{default:n(()=>[l(a(i),p(m(s.$props)),{default:n(()=>[l(a(f),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:n(()=>[e.loading?y("",!0):u(s.$slots,"default",{key:0})]),_:3})]),_:3},16)]),_:3},8,["title"])):(d(),r(a(i),p(B({key:1},s.$props)),{default:n(()=>[l(a(f),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:n(()=>[e.loading?y("",!0):u(s.$slots,"default",{key:0})]),_:3})]),_:3},16))}});export{w as _};
//# sourceMappingURL=AbstraButton.vue_vue_type_script_setup_true_lang-BDINAViH.js.map
