(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[t]="be972439-a96f-4c10-b2ac-e722ad3a6a34",n._sentryDebugIdIdentifier="sentry-dbid-be972439-a96f-4c10-b2ac-e722ad3a6a34")}catch{}})();function a(n,t,e){return t(e),e(n,t)}var m=/[a-z]/,o=/[A-Z]/,l=/[a-zA-Z0-9_]/,f=/[0-9]/,g=/[0-9A-Fa-f]/,p=/[-&*+.\\/<>=?^|:]/,w=/[(),[\]{}]/,v=/[ \v\f]/;function i(){return function(n,t){if(n.eatWhile(v))return null;var e=n.next();if(w.test(e))return e==="{"&&n.eat("-")?a(n,t,d(1)):e==="["&&n.match("glsl|")?a(n,t,x):"builtin";if(e==="'")return a(n,t,b);if(e==='"')return n.eat('"')?n.eat('"')?a(n,t,u):"string":a(n,t,y);if(o.test(e))return n.eatWhile(l),"type";if(m.test(e)){var r=n.pos===1;return n.eatWhile(l),r?"def":"variable"}if(f.test(e)){if(e==="0"){if(n.eat(/[xX]/))return n.eatWhile(g),"number"}else n.eatWhile(f);return n.eat(".")&&n.eatWhile(f),n.eat(/[eE]/)&&(n.eat(/[-+]/),n.eatWhile(f)),"number"}return p.test(e)?e==="-"&&n.eat("-")?(n.skipToEnd(),"comment"):(n.eatWhile(p),"keyword"):e==="_"?"keyword":"error"}}function d(n){return n==0?i():function(t,e){for(;!t.eol();){var r=t.next();if(r=="{"&&t.eat("-"))++n;else if(r=="-"&&t.eat("}")&&(--n,n===0))return e(i()),"comment"}return e(d(n)),"comment"}}function u(n,t){for(;!n.eol();){var e=n.next();if(e==='"'&&n.eat('"')&&n.eat('"'))return t(i()),"string"}return"string"}function y(n,t){for(;n.skipTo('\\"');)n.next(),n.next();return n.skipTo('"')?(n.next(),t(i()),"string"):(n.skipToEnd(),t(i()),"error")}function b(n,t){for(;n.skipTo("\\'");)n.next(),n.next();return n.skipTo("'")?(n.next(),t(i()),"string"):(n.skipToEnd(),t(i()),"error")}function x(n,t){for(;!n.eol();){var e=n.next();if(e==="|"&&n.eat("]"))return t(i()),"string"}return"string"}var k={case:1,of:1,as:1,if:1,then:1,else:1,let:1,in:1,type:1,alias:1,module:1,where:1,import:1,exposing:1,port:1};const E={name:"elm",startState:function(){return{f:i()}},copyState:function(n){return{f:n.f}},token:function(n,t){var e=t.f(n,function(h){t.f=h}),r=n.current();return k.hasOwnProperty(r)?"keyword":e},languageData:{commentTokens:{line:"--"}}};export{E as elm};
//# sourceMappingURL=elm-DiEQNcu0.js.map
