import{al as f}from"./jwt-decode.esm-BYfS37aG.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="783602cc-ee69-49af-b91f-7ba6bcf7f608",e._sentryDebugIdIdentifier="sentry-dbid-783602cc-ee69-49af-b91f-7ba6bcf7f608")}catch{}})();var r=4;function o(e){return f(e,r)}export{o as c};
//# sourceMappingURL=clone-BD6ZGkGy.js.map
