(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="13b27e1d-54bb-489e-a327-30149e2d871c",e._sentryDebugIdIdentifier="sentry-dbid-13b27e1d-54bb-489e-a327-30149e2d871c")}catch{}})();var u=/[^\s\|\!\+\-\*\?\~\^\&\:\(\)\[\]\{\}\"\\]/,f=/[\|\!\+\-\*\?\~\^\&]/,l=/^(OR|AND|NOT|TO)$/;function s(e){return parseFloat(e).toString()===e}function a(e){return function(n,t){for(var r=!1,o;(o=n.next())!=null&&!(o==e&&!r);)r=!r&&o=="\\";return r||(t.tokenize=i),"string"}}function d(e){return function(n,t){return e=="|"?n.eat(/\|/):e=="&"&&n.eat(/\&/),t.tokenize=i,"operator"}}function c(e){return function(n,t){for(var r=e;(e=n.peek())&&e.match(u)!=null;)r+=n.next();return t.tokenize=i,l.test(r)?"operator":s(r)?"number":n.peek()==":"?"propertyName":"string"}}function i(e,n){var t=e.next();return t=='"'?n.tokenize=a(t):f.test(t)?n.tokenize=d(t):u.test(t)&&(n.tokenize=c(t)),n.tokenize!=i?n.tokenize(e,n):null}const k={name:"solr",startState:function(){return{tokenize:i}},token:function(e,n){return e.eatSpace()?null:n.tokenize(e,n)}};export{k as solr};
//# sourceMappingURL=solr-DMW5Mv65.js.map
