(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="c0f64b23-b26c-4844-a13e-87de28986b9e",e._sentryDebugIdIdentifier="sentry-dbid-c0f64b23-b26c-4844-a13e-87de28986b9e")}catch{}})();var d=["From","Sender","Reply-To","To","Cc","Bcc","Message-ID","In-Reply-To","References","Resent-From","Resent-Sender","Resent-To","Resent-Cc","Resent-Bcc","Resent-Message-ID","Return-Path","Received"],o=["Date","Subject","Comments","Keywords","Resent-Date"],u=/^[ \t]/,l=/^From /,f=new RegExp("^("+d.join("|")+"): "),t=new RegExp("^("+o.join("|")+"): "),c=/^[^:]+:/,p=/^[^ ]+@[^ ]+/,b=/^.*?(?=[^ ]+?@[^ ]+)/,m=/^<.*?>/,s=/^.*?(?=<.*>)/;function v(e){return e==="Subject"?"header":"string"}function H(e,r){if(e.sol()){if(r.inSeparator=!1,r.inHeader&&e.match(u))return null;if(r.inHeader=!1,r.header=null,e.match(l))return r.inHeaders=!0,r.inSeparator=!0,"atom";var n,i=!1;return(n=e.match(t))||(i=!0)&&(n=e.match(f))?(r.inHeaders=!0,r.inHeader=!0,r.emailPermitted=i,r.header=n[1],"atom"):r.inHeaders&&(n=e.match(c))?(r.inHeader=!0,r.emailPermitted=!0,r.header=n[1],"atom"):(r.inHeaders=!1,e.skipToEnd(),null)}if(r.inSeparator)return e.match(p)?"link":(e.match(b)||e.skipToEnd(),"atom");if(r.inHeader){var a=v(r.header);if(r.emailPermitted){if(e.match(m))return a+" link";if(e.match(s))return a}return e.skipToEnd(),a}return e.skipToEnd(),null}const h={name:"mbox",startState:function(){return{inSeparator:!1,inHeader:!1,emailPermitted:!1,header:null,inHeaders:!1}},token:H,blankLine:function(e){e.inHeaders=e.inSeparator=e.inHeader=!1},languageData:{autocomplete:d.concat(o)}};export{h as mbox};
//# sourceMappingURL=mbox-Da05mgV7.js.map
