import{N as c}from"./Navbar-C7gdq3B3.js";import{e as d,ak as u,b as a,l,a4 as f,f as _,g as y,v as p,k as I,aO as v}from"./jwt-decode.esm-BYfS37aG.js";import"./logo-BiWG9_W5.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang-BDINAViH.js";import"./constants-BEWVx_ZC.js";import"./PhCaretDown.vue-DmkUWTJV.js";import"./PhPencilSimple.vue-acvKr7-y.js";import"./router-D53qV9Zg.js";import"./ts.worker-Biy-7fEJ.js";import"./organization-BI2IWMw4.js";import"./tables-nYEEmE6H.js";import"./string-IQGGUV40.js";import"./keyboard-B-p_GVKE.js";import"./os-TL1oT4EB.js";import"./projectStore-6bDmkbW0.js";import"./project-C7QI6pXl.js";import"./organizationSwitcher-DapMvF_6.js";import"./cascaderStore-DVmoq__x.js";import"./CreateProjectModal.vue_vue_type_script_setup_true_lang-Gs0BADce.js";import"./member-dJywfr1G.js";import"./index-BpdGQ8Tk.js";import"./index-DwiPTllg.js";import"./CreateTableModal.vue_vue_type_script_setup_true_lang-sO_Z1dX4.js";import"./PhNotePencil.vue-D_M8phfV.js";import"./PhSignOut.vue-DOsKwdz-.js";import"./index-DK-lC7kV.js";import"./index-B_8hGuYH.js";import"./PhPlus.vue-Cfof6k8O.js";import"./omniChatStore-BXiBucvC.js";import"./files-CCeYtlN6.js";import"./contracts.generated-CTgVTh-H.js";import"./runnerData-CFJzN8JX.js";import"./url-xbaQsfJ1.js";import"./colorHelpers-Dr5wl109.js";import"./uuid-CHgzk6MJ.js";import"./PhCopySimple.vue-CJw_R1hE.js";import"./PhSparkle.vue-CY2_k51j.js";import"./index-D5u_yjkD.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="d1f953e6-9af3-4e3e-9c79-11a028ce3983",e._sentryDebugIdIdentifier="sentry-dbid-d1f953e6-9af3-4e3e-9c79-11a028ce3983")}catch{}})();const g={class:"console-layout"},b={class:"console-content"},w=d({__name:"ConsoleLayout",setup(e){const o=u(),s=a(()=>!!o.params.projectId),n=a(()=>{const t=o.meta.pageNameKey;if(t)return t.startsWith("i18n_")?l.translateIfFound(t,null):t}),m=a(()=>{const t=o.params.projectId,i=o.params.tableId,r=o.params.organizationId;if(t)return{projectId:t,tableId:i,currentPageName:n.value};if(r)return{organizationId:r}});return(t,i)=>{const r=f("RouterView");return y(),_("div",g,[p(c,{"use-cascader":!0,"cascader-props":m.value,"show-ai-sparkles":s.value},null,8,["cascader-props","show-ai-sparkles"]),I("div",b,[p(r)])])}}}),io=v(w,[["__scopeId","data-v-62f8634d"]]);export{io as default};
//# sourceMappingURL=ConsoleLayout-Bky_6MbQ.js.map
