import{e as _,ag as f,ak as p,l as s,n as m,g as i,w as u,f as g,M as y,X as v,v as k,p as n,k as w,t as I}from"./jwt-decode.esm-BYfS37aG.js";import{u as T}from"./projectStore-6bDmkbW0.js";import{A as D,T as S}from"./index-DwiPTllg.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="5bef810a-a353-44a7-a9fd-b2b12310d929",e._sentryDebugIdIdentifier="sentry-dbid-5bef810a-a353-44a7-a9fd-b2b12310d929")}catch{}})();const N=_({__name:"TablesTabs",setup(e){const a=f(),r=p(),b=String(r.name),d=T(),o=[{label:s.translate("i18n_tablestabs_tables_list"),value:"tables"},{label:s.translate("i18n_tablestabs_diagram_view"),value:"tables-diagram"},{label:s.translate("i18n_tablestabs_run_sql"),value:"sql"}],c=l=>{a.push({name:String(l),params:{projectId:d.projectId}})};return(l,h)=>(i(),m(n(S),{"active-key":n(b),options:o,"onUpdate:activeKey":c},{default:u(()=>[(i(),g(y,null,v(o,t=>k(n(D),{key:t.value,name:t.value},{tab:u(()=>[w("span",null,I(t.label),1)]),_:2},1032,["name"])),64))]),_:1},8,["active-key"]))}});export{N as _};
//# sourceMappingURL=TablesTabs.vue_vue_type_script_setup_true_lang-DaI2alF5.js.map
