import{C as t,_ as p}from"./View.vue_vue_type_script_setup_true_lang-CkpP8jrK.js";import{e as i,n,g as s,p as m}from"./jwt-decode.esm-BYfS37aG.js";import{u as a}from"./projectStore-6bDmkbW0.js";import"./router-D53qV9Zg.js";import"./ts.worker-Biy-7fEJ.js";import"./fetch-DQISYrhY.js";import"./tables-nYEEmE6H.js";import"./string-IQGGUV40.js";import"./SaveButton-zn2s7jex.js";import"./ExclamationCircleOutlined-B3RoPv91.js";import"./CrudView-De6FzvpW.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-D4miJSwr.js";import"./constants-BEWVx_ZC.js";import"./url-xbaQsfJ1.js";import"./PhDotsThreeVertical.vue-LoLE_1MZ.js";import"./index-DK-lC7kV.js";import"./asyncComputed-Dxf4RCwC.js";import"./PhPencil.vue-SE2OwxBB.js";import"./useCodebaseEvents-8rA7qn9B.js";import"./contracts.generated-CTgVTh-H.js";import"./index-D2Zf-HsM.js";import"./project-C7QI6pXl.js";import"./organizationSwitcher-DapMvF_6.js";import"./organization-BI2IWMw4.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="4dfbe3ca-718a-46be-9632-4b1af1f7c4ab",o._sentryDebugIdIdentifier="sentry-dbid-4dfbe3ca-718a-46be-9632-4b1af1f7c4ab")}catch{}})();const z=i({__name:"EnvVars",setup(o){const r=a(),e=new t(r.projectId);return(f,c)=>(s(),n(p,{"env-var-repository":m(e),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars-CcvnfxSi.js.map
