import{P as f}from"./PlayerNavbar-8P26xy1l.js";import{e as _,ak as i,r as h,b,f as k,n as y,j as w,k as v,p as a,v as L,a4 as C,ag as I,g as c,aO as N}from"./jwt-decode.esm-BYfS37aG.js";import{u as V}from"./workspaceStore-CMQaTfN3.js";import"./userStore-ZzGDEfJ0.js";import"./metadata-9Sy_Y2Gz.js";import"./PhCursorClick.vue-mvNh3JMs.js";import"./PhHouse.vue-DRZ39az5.js";import"./PhMagnifyingGlass.vue-DmAWc16f.js";import"./PhWebhooksLogo.vue-2SCNyr8o.js";import"./LoadingOutlined-CyONonpC.js";import"./PhSignOut.vue-DOsKwdz-.js";import"./index-B_8hGuYH.js";import"./runnerData-CFJzN8JX.js";import"./url-xbaQsfJ1.js";import"./colorHelpers-Dr5wl109.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="0202ea84-f937-4cb3-9cb8-605036481111",o._sentryDebugIdIdentifier="sentry-dbid-0202ea84-f937-4cb3-9cb8-605036481111")}catch{}})();const B={class:"main-container"},D={class:"content"},P=_({__name:"Main",setup(o){const e=I(),t=V(),p=i().path,n=h(null),u=async({path:r,id:s})=>{n.value=s,await e.push({path:`/${r}`}),n.value=null},d=()=>{e.push({name:"playerLogin"})},l=()=>{e.push({name:"playerLogin"})},m=b(()=>!!i().meta.hideLogin);return(r,s)=>{const g=C("RouterView");return c(),k("div",B,[a(t).state.workspace?(c(),y(f,{key:0,"current-path":a(p),"hide-login":m.value,"runner-data":a(t).state.workspace,loading:n.value,"show-sidebar":a(t).state.currentPageType==="form",onNavigate:u,onLoginClick:l,onLogoutClick:d},null,8,["current-path","hide-login","runner-data","loading","show-sidebar"])):w("",!0),v("section",D,[L(g)])])}}}),H=N(P,[["__scopeId","data-v-61bdccea"]]);export{H as default};
//# sourceMappingURL=Main-CT3_-qZo.js.map
