import{_ as i}from"./NewEditor-BRnn5ufh.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[s]="7dd701fe-7e25-49c6-ac3b-36173b32b948",t._sentryDebugIdIdentifier="sentry-dbid-7dd701fe-7e25-49c6-ac3b-36173b32b948")}catch{}})();var e,n=(e=class{constructor(s){this.init=s,this.records=this.init()}reset(){this.records=this.init()}},i(e,"ImperativeState"),e);export{n as I};
//# sourceMappingURL=chunk-QZHKN3VN-GDnUDpaS.js.map
